@@ -1,5 +1,5 @@
 /* Extended Module Player
- * Copyright (C) 1996-2009 Claudio Matsuoka and Hipolito Carraro Jr
+ * Copyright (C) 1996-2010 Claudio Matsuoka and Hipolito Carraro Jr
  * AWE32 support Copyright (C) 1996, 1997 Takashi Iwai
  *
  * This file is part of the Extended Module Player and is distributed
@@ -261,7 +261,7 @@ static void bufdump()
 			if ((read(seqfd, &echo_msg, 4) == 4) &&
 			    ((echo_msg & 0xff) == SEQ_ECHO)) {
 				echo_msg >>= 8;
-				p_ctx->event_callback(echo_msg);
+				p_ctx->event_callback(echo_msg, p_ctx->callback_data);
 			} else
 				echo_msg = 0;	/* ECHO_NONE */
 		}
