@@ -75,6 +75,7 @@
 #define FX_FLT_CUTOFF	0x84
 #define FX_FLT_RESN	0x85
 #define FX_FINE2_VIBRA	0x86
+#define FX_IT_BPM	0x87
 
 /* MED effects */
 #define FX_HOLD_DECAY	0x90
@@ -97,6 +98,5 @@
 #define FX_REVERB	0xaa	/* IMF */
 #define FX_S3M_BPM	0xab	/* S3M */
 #define FX_FINE4_VIBRA	0xac	/* S3M/PTM/IMF/LIQ */
-#define FX_IT_BPM	0xad	/* IT */
 
 #endif /* __EFFECTS_H */
