@@ -1,5 +1,5 @@
 /* Extended Module Player
- * Copyright (C) 1996-2009 Claudio Matsuoka and Hipolito Carraro Jr
+ * Copyright (C) 1996-2010 Claudio Matsuoka and Hipolito Carraro Jr
  *
  * This file is part of the Extended Module Player and is distributed
  * under the terms of the GNU General Public License. See doc/COPYING
@@ -29,7 +29,8 @@ static int flt_test(FILE *f, char *t, const int start)
     char buf[4];
 
     fseek(f, start + 1080, SEEK_SET);
-    fread(buf, 4, 1, f);
+    if (fread(buf, 1, 4, f) < 4)
+	return -1;
 
     /* Also RASP? */
     if (memcmp(buf, "FLT", 3) && memcmp(buf, "EXO", 3))
@@ -96,7 +97,8 @@ static int is_am_instrument(FILE *nt, int i)
     int16 wf;
 
     fseek(nt, 144 + i * 120, SEEK_SET);
-    fread(buf, 1, 2, nt);
+    if (fread(buf, 1, 2, nt) < 2)
+	return 0;
     if (memcmp(buf, "AM", 2))
 	return 0;
 
