@@ -1,5 +1,5 @@
 /* Extended Module Player
- * Copyright (C) 1996-2009 Claudio Matsuoka and Hipolito Carraro Jr
+ * Copyright (C) 1996-2010 Claudio Matsuoka and Hipolito Carraro Jr
  *
  * This file is part of the Extended Module Player and is distributed
  * under the terms of the GNU General Public License. See doc/COPYING
@@ -76,7 +76,9 @@ static int ims_test(FILE *f, char *t, const int start)
     fread(&ih.title, 20, 1, f);
 
     for (i = 0; i < 31; i++) {
-	fread(&ih.ins[i].name, 20, 1, f);
+	if (fread(&ih.ins[i].name, 1, 20, f) < 20)
+	    return -1;
+
 	ih.ins[i].finetune = (int16)read16b(f);
 	ih.ins[i].size = read16b(f);
 	ih.ins[i].unknown = read8(f);
