@@ -75,7 +75,9 @@ char *test_xfd		(unsigned char *, int);
 #define REDIR_STDERR
 #endif
 
-static int decrunch(struct xmp_context *ctx, FILE **f, char **s)
+#define DECRUNCH_MAX 5 /* don't recurse more than this */
+
+static int decrunch(struct xmp_context *ctx, FILE **f, char **s, int ttl)
 {
     struct xmp_options *o = &ctx->o;
     unsigned char b[1024];
@@ -84,6 +86,7 @@ static int decrunch(struct xmp_context *ctx, FILE **f, char **s)
     int fd, builtin, res;
     char *packer, *temp2, tmp[PATH_MAX];
     struct tmpfilename *temp;
+    int headersize;
 
     packer = cmd = NULL;
     builtin = res = 0;
@@ -94,7 +97,7 @@ static int decrunch(struct xmp_context *ctx, FILE **f, char **s)
     strncat(tmp, "xmp_XXXXXX", PATH_MAX);
 
     fseek(*f, 0, SEEK_SET);
-    if (fread(b, 1, 1024, *f) < 100)	/* minimum valid file size */
+    if ((headersize = fread(b, 1, 1024, *f)) < 100)	/* minimum valid file size */
 	return 0;
 
 #if defined __AMIGA__ && !defined __AROS__
@@ -102,7 +105,11 @@ static int decrunch(struct xmp_context *ctx, FILE **f, char **s)
 	builtin = BUILTIN_XFD;
     } else
 #endif
-    if (b[0] == 'P' && b[1] == 'K' && b[2] == 0x03 && b[3] == 0x04) {
+
+    if (b[0] == 'P' && b[1] == 'K' &&
+	((b[2] == 3 && b[3] == 4) || (b[2] == '0' && b[3] == '0' &&
+	b[4] == 'P' && b[5] == 'K' && b[6] == 3 && b[7] == 4))) {
+
 	packer = "Zip";
 #if defined WIN32
 	cmd = "unzip -pqqC \"%s\" -x readme *.diz *.nfo *.txt *.exe *.com "
@@ -139,6 +146,13 @@ static int decrunch(struct xmp_context *ctx, FILE **f, char **s)
     } else if (b[0] == 'M' && b[1] == 'O' && b[2] == '3') {
 	packer = "MO3";
 	cmd = "unmo3 -s \"%s\" STDOUT";
+    } else if (headersize > 300 &&
+	       b[257] == 'u' && b[258] == 's' && b[259] == 't' &&
+	       b[260] == 'a' && b[261] == 'r' &&
+	       ((b[262] == 0) || (b[262] == ' ' && b[263] == ' ' &&
+				  b[264] == 0))) {
+	packer = "tar";
+	cmd = "tar -xOf \"%s\"";
     } else if (b[0] == 31 && b[1] == 157) {
 	packer = "compress";
 #ifdef __EMX__
@@ -325,8 +339,11 @@ static int decrunch(struct xmp_context *ctx, FILE **f, char **s)
     fclose(*f);
     *f = t;
  
+    if (!--ttl)
+	    goto err;
+    
     temp2 = strdup(temp->name);
-    decrunch(ctx, f, &temp->name);
+    res = decrunch(ctx, f, &temp->name, ttl);
     unlink(temp2);
     free(temp2);
     /* Mirko: temp is now deallocated in xmp_unlink_tempfiles
@@ -336,7 +353,7 @@ static int decrunch(struct xmp_context *ctx, FILE **f, char **s)
      * free(temp);
      */
 
-    return 1;
+    return res;
 
 err:
     return -1;
@@ -443,7 +460,7 @@ int xmp_test_module(xmp_context ctx, char *s, char *n)
     if (S_ISDIR(st.st_mode))
 	goto err;
 
-    if (decrunch((struct xmp_context *)ctx, &f, &s) < 0)
+    if (decrunch((struct xmp_context *)ctx, &f, &s, DECRUNCH_MAX) < 0)
 	goto err;
 
     if (fstat(fileno(f), &st) < 0)	/* get size after decrunch */
@@ -516,7 +533,7 @@ int xmp_load_module(xmp_context ctx, char *s)
 	goto err;
 
     _D(_D_INFO "decrunch");
-    if ((t = decrunch((struct xmp_context *)ctx, &f, &s)) < 0)
+    if ((t = decrunch((struct xmp_context *)ctx, &f, &s, DECRUNCH_MAX)) < 0)
 	goto err;
 
     if (fstat(fileno(f), &st) < 0)	/* get size after decrunch */
@@ -725,9 +742,9 @@ void xmp_release_module(xmp_context ctx)
 		free(m->xxp[i]);
 
 	for (i = 0; i < m->xxh->ins; i++) {
-		free(m->xxfe[i]);
-		free(m->xxpe[i]);
-		free(m->xxae[i]);
+		if (m->xxfe[i]) free(m->xxfe[i]);
+		if (m->xxpe[i]) free(m->xxpe[i]);
+		if (m->xxae[i]) free(m->xxae[i]);
 		free(m->xxi[i]);
 	}
 
