@@ -159,8 +159,8 @@ void smix_resetvar(struct xmp_context *ctx)
     struct xmp_options *o = &ctx->o;
 
     s->ticksize = m->quirk & XMP_QRK_MEDBPM ?
-	o->freq * m->rrate * 33 / p->xmp_bpm / 12500 :
-    	o->freq * m->rrate / p->xmp_bpm / 100;
+	o->freq * m->rrate * 33 / p->bpm / 12500 :
+    	o->freq * m->rrate / p->bpm / 100;
 
     if (s->buf32b) {
 	s->dtright = s->dtleft = 0;
