@@ -36,7 +36,6 @@
 #include "player.h"
 #include "synth.h"
 
-
 /* Values for multi-retrig */
 static struct retrig_t rval[] = {
     {   0,  1,  1 }, {  -1,  1,  1 }, {  -2,  1,  1 }, {  -4,  1,  1 },
@@ -86,8 +85,6 @@ static int waveform[4][64] = {
 static int fetch_channel (struct xmp_context *, struct xxm_event *, int, int);
 static void play_channel (struct xmp_context *, int, int);
 
-/* #include "effects.c" */
-
 
 static void dummy(unsigned long ul, void *data)
 {
@@ -187,7 +184,7 @@ static inline void reset_channel(struct xmp_context *ctx)
     int i;
     struct xmp_channel *xc;
 
-    synth_reset ();
+    synth_reset();
     memset(p->xc_data, 0, sizeof (struct xmp_channel) * d->numchn);
 
     for (i = d->numchn; i--; ) {
@@ -227,16 +224,6 @@ static inline void fetch_row(struct xmp_context *ctx, int ord, int row)
 }
 
 
-static inline void play_frame(struct xmp_context *ctx, int tick)
-{ 
-    struct xmp_driver_context *d = &ctx->d;
-    int i;
-
-    for (i = 0; i < d->numchn; i++)
-	play_channel(ctx, i, tick);
-}
-
-
 static int fetch_channel(struct xmp_context *ctx, struct xxm_event *e, int chn, int ctl)
 {
     struct xmp_player_context *p = &ctx->p;
@@ -413,6 +400,7 @@ static int fetch_channel(struct xmp_context *ctx, struct xxm_event *e, int chn,
     xc->a_idx = 0;
     xc->a_size = 1;
     xc->a_val[0] = 0;
+    xc->tremor = 0;
 
     if ((uint32)xins >= m->xxh->ins || !m->xxih[xins].nsm) {
 	RESET(IS_VALID);
@@ -858,8 +846,8 @@ int _xmp_player_start(struct xmp_context *ctx)
 	if (m->xxh->len == 0 || m->xxh->chn == 0) {
 		/* set variables to sane state */
 		m->flags &= ~XMP_CTL_LOOP;
-		f->ord = p->xmp_scan_ord = 0;
-		f->row = p->xmp_scan_row = 0;
+		f->ord = p->scan_ord = 0;
+		f->row = p->scan_row = 0;
 		f->end_point = 0;
 		return 0;
 	}
@@ -871,11 +859,11 @@ int _xmp_player_start(struct xmp_context *ctx)
 		f->ord++;
 
 	m->volume = m->xxo_info[f->ord].gvl;
-	p->tick_time = m->rrate / (p->xmp_bpm = m->xxo_info[f->ord].bpm);
+	p->tick_time = m->rrate / (p->bpm = m->xxo_info[f->ord].bpm);
 	p->tempo = m->xxo_info[f->ord].tempo;
 	f->jumpline = m->xxo_fstrow[f->ord];
 	f->playing_time = 0;
-	f->end_point = p->xmp_scan_num;
+	f->end_point = p->scan_num;
 
 	if ((ret = xmp_drv_on(ctx, m->xxh->chn)) != 0)
 		return ret;
@@ -903,6 +891,7 @@ int _xmp_player_frame(struct xmp_context *ctx)
 	struct xmp_mod_context *m = &p->m;
 	struct xmp_options *o = &ctx->o;
 	struct flow_control *f = &p->flow;
+	int i;
 
 	if (p->pause) {
 		p->event_callback(0, p->callback_data);
@@ -920,13 +909,13 @@ int _xmp_player_frame(struct xmp_context *ctx)
 		}
 
 		if (p->pos == 0)
-			f->end_point = p->xmp_scan_num;
+			f->end_point = p->scan_num;
 
 		f->ord = p->pos;
 		if (m->xxo_info[f->ord].tempo)
 			p->tempo = m->xxo_info[f->ord].tempo;
-		p->xmp_bpm = m->xxo_info[f->ord].bpm;
-		p->tick_time = m->rrate / p->xmp_bpm;
+		p->bpm = m->xxo_info[f->ord].bpm;
+		p->tick_time = m->rrate / p->bpm;
 		m->volume = m->xxo_info[f->ord].gvl;
 		f->jump = f->ord;
 		f->time = (double)m->xxo_info[f->ord].time / 1000;
@@ -945,8 +934,8 @@ int _xmp_player_frame(struct xmp_context *ctx)
 
 	if (f->frame == 0) {			/* first frame in row */
 		/* check end of module */
-	    	if ((~m->flags & XMP_CTL_LOOP) && f->ord == p->xmp_scan_ord &&
-					f->row == p->xmp_scan_row) {
+	    	if ((~m->flags & XMP_CTL_LOOP) && f->ord == p->scan_ord &&
+					f->row == p->scan_row) {
 			if (!f->end_point--)
 				return -1;
 		}
@@ -954,7 +943,7 @@ int _xmp_player_frame(struct xmp_context *ctx)
 		p->gvol_flag = 0;
 		fetch_row(ctx, m->xxo[f->ord], f->row);
 
-		xmp_drv_echoback(ctx, (p->tempo << 12) | (p->xmp_bpm << 4) |
+		xmp_drv_echoback(ctx, (p->tempo << 12) | (p->bpm << 4) |
 							XMP_ECHO_BPM);
 		xmp_drv_echoback(ctx, (m->volume << 4) | XMP_ECHO_GVL);
 		xmp_drv_echoback(ctx, (m->xxo[f->ord] << 12) | (f->ord << 4) |
@@ -968,19 +957,21 @@ int _xmp_player_frame(struct xmp_context *ctx)
 
 
 	xmp_drv_echoback(ctx, (f->frame << 4) | XMP_ECHO_FRM);
-	play_frame(ctx, f->frame);
+	/* play_frame */
+	for (i = 0; i < d->numchn; i++)
+		play_channel(ctx, i, f->frame);
 
 	if (o->time && (o->time < f->playing_time))	/* expired time */
 		return -1;
 
 	if (HAS_QUIRK(XMP_QRK_MEDBPM)) {
 		xmp_drv_sync(ctx, p->tick_time * 33 / 125);
-		f->playing_time += m->rrate * 33 / (100 * p->xmp_bpm * 125);
-		f->time += m->rrate * 33 / (100 * p->xmp_bpm * 125);
+		f->playing_time += m->rrate * 33 / (100 * p->bpm * 125);
+		f->time += m->rrate * 33 / (100 * p->bpm * 125);
 	} else {
 		xmp_drv_sync(ctx, p->tick_time);
-		f->playing_time += m->rrate / (100 * p->xmp_bpm);
-		f->time += m->rrate / (100 * p->xmp_bpm);
+		f->playing_time += m->rrate / (100 * p->bpm);
+		f->time += m->rrate / (100 * p->bpm);
 	}
 
 	f->frame++;
@@ -1070,5 +1061,4 @@ void _xmp_player_end(struct xmp_context *ctx)
 	free(f->loop_start);
 	free(f->loop_stack);
 	free(p->fetch_ctl);
-
 }
