@@ -1,5 +1,5 @@
 /* Extended Module Player
- * Copyright (C) 1996-2009 Claudio Matsuoka and Hipolito Carraro Jr
+ * Copyright (C) 1996-2010 Claudio Matsuoka and Hipolito Carraro Jr
  *
  * This file is part of the Extended Module Player and is distributed
  * under the terms of the GNU General Public License. See doc/COPYING
@@ -77,6 +77,9 @@ int _xmp_read_rc(struct xmp_context *ctx)
 
     if ((rc = fopen(myrc, "r")) == NULL)
 	return -1;
+#elif defined ANDROID
+    if ((rc = fopen("/sdcard/xmp/xmp.conf", "r")) == NULL)
+	return -1;
 #else
     char *home = getenv("HOME");
 
@@ -251,6 +254,8 @@ void _xmp_read_modconf(struct xmp_context *ctx, uint32 crc, long size)
 
     snprintf(myrc, PATH_MAX, "%s/modules.ini", home);
     parse_modconf(ctx, myrc, crc, size);
+#elif defined ANDROID
+    parse_modconf(ctx, "/sdcard/xmp/modules.conf", crc, size);
 #else
     char myrc[PATH_MAX];
     char *home = getenv ("HOME");
